@@ -1,15 +1,16 @@
 package LWP::UserAgent::Patch::Retry;
 
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.03'; # VERSION
+
 use 5.010001;
 use strict;
 no warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Module::Patch 0.12 qw();
 use base qw(Module::Patch);
 
-our $VERSION = '0.02'; # VERSION
-
 our %config;
 
 my $p_send_request = sub {
@@ -74,7 +75,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -82,7 +83,7 @@ LWP::UserAgent::Patch::Retry - Add retries
 
 =head1 VERSION
 
-version 0.02
+This document describes version 0.03 of LWP::UserAgent::Patch::Retry (from Perl distribution LWP-UserAgent-Patch-Retry), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -125,10 +126,6 @@ you do not want to retry on 404 errors:
 By patching, you do not need to replace all the client code which uses
 LWP::UserAgent (or WWW::Mechanize, and so on).
 
-=head1 TODO
-
-More complex retrying delays (exponential backoff).
-
 =head1 SEE ALSO
 
 L<LWP::UserAgent::Determined>, L<LWP::UserAgent::ExponentialBackoff>
@@ -145,8 +142,7 @@ Source repository is at L<https://github.com/sharyanto/perl-LWP-UserAgent-Patch-
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/Public/Dist/Display.html?Name=LWP-UserAgent-Patch-Retry
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=LWP-UserAgent-Patch-Retry>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -154,11 +150,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
